@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2005-2010 Thierry FOURNIER
- * $Id: loadconfig.c 450 2006-11-24 10:33:55Z thierry $
+ * $Id: loadconfig.c 508 2007-06-07 09:12:02Z thierry $
  *
  */
 
@@ -188,6 +188,9 @@ void config_load(int argc, char *argv[]){
 	config[CF_DUMP_PAQUET].type = 2;
 	config[CF_DUMP_PAQUET].attrib = "dump paquet";
 	config[CF_DUMP_PAQUET].valeur.integer = FALSE;
+	config[CF_DUMP_PACKET].type = 2;
+	config[CF_DUMP_PACKET].attrib = "dump packet";
+	config[CF_DUMP_PACKET].valeur.integer = FALSE;
 
 	config[CF_PROMISC].type = 2;
 	config[CF_PROMISC].attrib = "promiscuous";
@@ -351,8 +354,8 @@ void config_load(int argc, char *argv[]){
 		}
 	}
 
-	/* load command line parameters 
-	 * (this supplant config file params) */
+	// load command line parameters
+	// (this supplant config file params)
 	for(i=1; i<argc; i++){
 		if(argv[i][0]=='-'){
 			switch(argv[i][1]){
@@ -461,8 +464,15 @@ void config_load(int argc, char *argv[]){
 		for(i=0; i<NUM_PARAMS; i++){
 			switch(config[i].type){
 				case 0:
-					logmsg(LOG_NOTICE, "%s = \"%s\"",*
-					       config[i].attrib, config[i].valeur.string);
+					if(config[i].valeur.string == NULL){
+						logmsg(LOG_NOTICE, "%s = \"\"",
+						       config[i].attrib);
+					}
+
+					else {
+						logmsg(LOG_NOTICE, "%s = \"%s\"",
+						       config[i].attrib, config[i].valeur.string);
+					}
 				break;
 
 				case 1:
